@@ -1383,14 +1383,13 @@ def test_query_first(server):
 
 def test_query_limit(server):
     query = server.query("Patient")
-    query._count = 30
-    result = query.limit(100, page_callback=lambda x: print(len(x)))
-    assert len(result.resources) == 100
+    query._count = 5
+    result = query.limit(20, page_callback=lambda x: print(len(x)))
+    assert len(result.resources) == 20
 
     query = server.query("Patient", output_format="xml").all(count=50)
 
 
-
 def test_query_with_callback(server):
     print("callback1")
     result = server.query("Patient").all(page_callback=lambda: print("callback"), count=50)
@@ -1400,8 +1399,7 @@ def test_query_with_callback(server):
 
     print("callback3")
     with pytest.raises(ValueError):
-
-        server.query("Patient").all(page_callback=lambda x,y: print(x, y), count=20)
+        server.query("Patient").all(page_callback=lambda x, y: print(x, y), count=20)
 
 
 def test_query_response_resources(server):
@@ -1745,15 +1743,34 @@ def test_query_response_to_dfs(server):
 async def test_query_async(server):
     query = server.query_async("Patient")
     response = await query.all()
-    print(response)
+    assert response.resources
 
     with pytest.raises(ValueError):
         query = server.query_async("Patient", output_format="invalid")
         response = await query.all()
-        print(response)
+
 
 @pytest.mark.asyncio
 async def test_query_async_xml(server):
     query = server.query_async("Patient", output_format="xml")
     response = await query.all()
-    print(response)
\ No newline at end of file
+    assert response
+
+    with pytest.raises(NotImplementedError):
+        resources = response.resources
+
+
+@pytest.mark.asyncio
+async def test_query_async_first(server):
+    query = server.query_async("Patient")
+    response = await query.first()
+    print(response)
+    assert len(response.resources) == 1
+
+
+@pytest.mark.asyncio
+async def test_query_async_limit(server):
+    query = server.query_async("Patient")
+    response = await query.limit(10)
+    print(response)
+    assert len(response.resources) == 10
